Learn R Programming

SAME (version 0.1.0)

find.cutoffs: Function to calibrate the cutoff points under null hypothesis

Description

This function is used to calibrate the cutoff points under null hypothesis using a multi-arm multi-stage biomarker-enriched design with time-to-event endpoints.

Usage

find.cutoffs(
  median.c,
  K,
  L,
  lfu,
  alpha,
  power,
  accrate,
  theta,
  bio.preva,
  FAtime.phase3,
  N.iter
)

Value

find.cutoffs() returns the calibrated cutoff points that can control the type I error rate.

Arguments

median.c

The median survival time for control group

K

Number of biomarkers

L

Information fraction in terms of the accumulative events in phase II stage, e.g., K = c(1/4,1/2,1)

lfu

Follow-up time

alpha

One-sided familywise error rate

power

Power

accrate

Accrual rate

theta

A clinically meaningful treatment effect size defined by clinicians

bio.preva

Prevalence of biomarker(s)

FAtime.phase3

the study ending time of phase III

N.iter

Number of iterations

Examples

Run this code
# \donttest{
find.cutoffs(median.c=12,K=2,L=c(1/4,1/2,1),lfu=0,alpha=0.05,power=0.9,
             accrate=15,theta=log(1.25),bio.preva=c(0.4,0.6),FAtime.phase3=48,
             N.iter=3)# }

Run the code above in your browser using DataLab